@@ -1,5 +1,5 @@
 /*
-* libtcod 1.6.3
+* libtcod 1.6.4
 * Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
@@ -28,6 +28,11 @@
 #ifndef _TCOD_BSP_HPP
 #define _TCOD_BSP_HPP
 
+#include "bsp.h"
+#include "list.hpp"
+#include "mersenne.hpp"
+#include "tree.hpp"
+
 class TCODBsp;
 
 class TCODLIB_API ITCODBspCallback {
@@ -48,7 +53,7 @@ public :
 	int x,y,w,h; // 
 	int position; // position of splitting
 	bool horizontal; // horizontal splitting ?
-	uint8 level; // level in the tree 
+	uint8_t level; // level in the tree 
 	
 	/**
 	@PageName bsp_init
@@ -222,7 +227,7 @@ You can use it if you changed the nodes size and position while using the BSP tr
 			int x,y,w,h; // 
 			int position; // position of splitting
 			bool horizontal; // horizontal splitting ?
-			uint8 level; // level in the tree 
+			uint8_t level; // level in the tree 
 			...
 		}
 	@C 
@@ -230,7 +235,7 @@ You can use it if you changed the nodes size and position while using the BSP tr
 			int x,y,w,h;
 			int position;
 			bool horizontal;
-			uint8 level;
+			uint8_t level;
 			...
 		} TCOD_bsp_t;
 	@C# 
