@@ -1,5 +1,5 @@
 /*
-* libtcod 1.6.3
+* libtcod 1.6.4
 * Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
@@ -28,10 +28,9 @@
 #ifndef _TCOD_FOV_HPP
 #define _TCOD_FOV_HPP
 
-#include "fov_types.h"
+#include "fov.h"
 
 class TCODPath;
-
 /**
  @PageName fov
  @PageCategory Roguelike toolkits
