@@ -1,5 +1,5 @@
 /*
-* libtcod 1.6.3
+* libtcod 1.6.4
 * Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
@@ -29,22 +29,6 @@
 
 #include "libtcod.hpp"
 
-#ifdef TCOD_VISUAL_STUDIO
-#pragma warning(disable:4996)
-#pragma warning(disable:4251)
-#endif
-
-// DLL export
-#ifdef TCOD_WINDOWS
-#ifdef LIBTCOD_GUI_EXPORTS
-#define TCODLIB_GUI_API __declspec(dllexport)
-#else
-#define TCODLIB_GUI_API __declspec(dllimport)
-#endif
-#else
-#define TCODLIB_GUI_API
-#endif
-
 #include "widget.hpp"
 #include "button.hpp"
 #include "radiobutton.hpp"
