@@ -1,5 +1,5 @@
 /*
-* libtcod 1.6.3
+* libtcod 1.6.4
 * Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
@@ -28,9 +28,18 @@
 #ifndef _TCOD_IMAGE_HPP
 #define _TCOD_IMAGE_HPP
 
-class TCODImage;
+#include "color.hpp"
 
+#ifdef TCOD_IMAGE_SUPPORT
+
+#ifdef TCOD_CONSOLE_SUPPORT
 #include "console.hpp"
+#endif
+#include "image.h"
+
+#ifdef TCOD_CONSOLE_SUPPORT
+class TCODConsole;
+#endif
 
 class TCODLIB_API TCODImage {
 public :
@@ -74,6 +83,7 @@ public :
 	*/	
 	TCODImage(const char *filename);
 	
+#ifdef TCOD_CONSOLE_SUPPORT
 	/**
 	@PageName image_create
 	@FuncTitle Creating an image from a console
@@ -115,6 +125,7 @@ public :
 		libtcod.image_refresh_console(pix,0)
 	*/
 	void refreshConsole(const TCODConsole *console);
+#endif
 
 	/**
 	@PageName image_read
@@ -338,6 +349,7 @@ public :
 	  */	
 	void save(const char *filename) const;
 
+#ifdef TCOD_CONSOLE_SUPPORT
 	/**
 	@PageName image_blit
 	@PageFather image
@@ -382,6 +394,8 @@ public :
 	@Param angle	Rotation angle in radians.
 	*/	
 	void blit(TCODConsole *console, float x, float y, TCOD_bkgnd_flag_t bkgnd_flag = TCOD_BKGND_SET, float scalex=1.0f, float scaley=1.0f, float angle=0.0f) const;
+#endif
+
 	/**
 	@PageName image_blit
 	@FuncTitle Blitting with a mask
@@ -407,7 +421,8 @@ public :
 		libtcod.image_blit_rect(pix,0,40,25,5,5,libtcod.BKGND_SET)
 	*/	
 	void setKeyColor(const TCODColor keyColor);
-	
+
+#ifdef TCOD_CONSOLE_SUPPORT
 	/**
 	@PageName image_blit
 	@FuncTitle Blitting with subcell resolution
@@ -434,6 +449,7 @@ public :
 	@Param sx,sy,w,h	Part of the image to blit. Use -1 in w and h to blit the whole image.
 	*/	
 	void blit2x(TCODConsole *dest, int dx, int dy, int sx=0, int sy=0, int w=-1, int h=-1) const;
+#endif
 
 	TCODImage(TCOD_image_t img) : data(img), deleteData(false) {}
 	virtual ~TCODImage();
@@ -445,4 +461,6 @@ protected :
 	bool deleteData;
 };
 
-#endif
+#endif /* TCOD_IMAGE_SUPPORT */
+
+#endif /* _TCOD_IMAGE_HPP */
