@@ -1,5 +1,5 @@
 /*
-* libtcod 1.6.3
+* libtcod 1.6.4
 * Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
@@ -32,31 +32,27 @@
 #if defined(__ANDROID__)
 #include <android/log.h>
 #endif
+#ifdef TCOD_SDL2
 #include <SDL.h>
+#endif
+
+#include "libtcod_portability.h"
+#include "color.h"
+#include "console_types.h"
+#include "fov.h"
+#include "fov_types.h"
+#include "mersenne_types.h"
+#include "sys.h"
 
 /* tcodlib internal stuff */
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-/* a cell in the console */
+#ifdef TCOD_CONSOLE_SUPPORT
 typedef struct {
-	int c;		/* character ascii code */
-	int cf;		/* character number in font */
-	uint8 dirty;	/* cell modified since last flush ? */
-} char_t;
-
-/* TCODConsole non public data */
-typedef struct {
-	TCOD_image_t fg_colors, fg_colors_prev;
-	TCOD_image_t bg_colors, bg_colors_prev;
-	char_t *buf; /* current console */
-	char_t *oldbuf; /* console for last frame */
-	uint8 clear_screen;
-} TCOD_render_state_t;
-
-typedef struct {
-	TCOD_render_state_t state;
+	int *ch_array; /* character code array */
+	TCOD_image_t fg_colors, bg_colors;
 	/* console width and height (in characters,not pixels) */
 	int w,h;
 	/* default background operator for print & print_rect functions */
@@ -65,8 +61,8 @@ typedef struct {
 	TCOD_alignment_t alignment;
 	/* foreground (text), background colors */
 	TCOD_color_t fore, back;
-	uint8 fade;
 } TCOD_console_data_t;
+#endif
 
 /* fov internal stuff */
 typedef struct {
@@ -89,11 +85,11 @@ typedef struct {
 	/* distribution */
 	TCOD_distribution_t distribution;
 	/* Mersenne Twister stuff */
-	uint32 mt[624];
+	uint32_t mt[624];
 	int cur_mt;
 	/* Complementary-Multiply-With-Carry stuff */
 	/* shared with Generalised Feedback Shift Register */
-	uint32 Q[4096], c;
+	uint32_t Q[4096], c;
     int cur;
 } mersenne_data_t;
 
@@ -114,6 +110,7 @@ typedef struct {
 	int *ascii_to_tcod;
 	/* whether each character in the font is a colored tile */
 	bool *colored;
+#ifdef TCOD_CONSOLE_SUPPORT
 	/* the root console */
 	TCOD_console_data_t *root;
 	/* nb chars in the font */
@@ -128,20 +125,27 @@ typedef struct {
 	/* actual resolution */
 	int actual_fullscreen_width;
 	int actual_fullscreen_height;
+#endif
+#ifdef TCOD_SDL2
 	/* renderer to use */
 	TCOD_renderer_t renderer;
 	/* user post-processing callback */
 	SDL_renderer_t sdl_cbk;
+#endif
 	/* fading data */
 	TCOD_color_t fading_color;
-	uint8 fade;
+	uint8_t fade;
+#ifdef TCOD_CONSOLE_SUPPORT
 	TCOD_key_t key_state;
+#endif
+#ifdef TCOD_SDL2
 	/* application window was closed */
 	bool is_window_closed;
 	/* application has mouse focus */
 	bool app_has_mouse_focus;
 	/* application is active (not iconified) */
 	bool app_is_active;
+#endif
 } TCOD_internal_context_t;
 
 extern TCOD_internal_context_t TCOD_ctx;
@@ -175,22 +179,24 @@ extern TCOD_internal_context_t TCOD_ctx;
 #define TCOD_LOG(x) printf x
 #endif
 
-#ifndef NO_OPENGL
+#if defined(TCOD_SDL2) && !defined(NO_OPENGL)
 /* opengl utilities */
 void TCOD_opengl_init_attributes(void);
 bool TCOD_opengl_init_state(int conw, int conh, void *font_tex);
+void TCOD_opengl_uninit_state(void);
 bool TCOD_opengl_init_shaders(void);
-bool TCOD_opengl_render(int oldFade, bool *ascii_updated, char_t *console_buffer, char_t *prev_console_buffer);
+bool TCOD_opengl_render(int oldFade, bool *ascii_updated, TCOD_console_data_t *console, TCOD_console_data_t *cache);
 void TCOD_opengl_swap(void);
 void * TCOD_opengl_get_screen(void);
 #endif
 
+#ifdef TCOD_IMAGE_SUPPORT
 /* image internal stuff */
-
 bool TCOD_image_mipmap_copy_internal(TCOD_image_t srcImage, TCOD_image_t dstImage);
 TCOD_color_t *TCOD_image_get_colors(TCOD_image_t *image);
 void TCOD_image_invalidate_mipmaps(TCOD_image_t *image);
 void TCOD_image_get_key_data(TCOD_image_t image, bool *has_key_color, TCOD_color_t *key_color);
+#endif
 
 /* fov internal stuff */
 void TCOD_map_compute_fov_circular_raycasting(TCOD_map_t map, int player_x, int player_y, int max_radius, bool light_walls);
@@ -200,19 +206,22 @@ void TCOD_map_compute_fov_permissive2(TCOD_map_t map, int player_x, int player_y
 void TCOD_map_compute_fov_restrictive_shadowcasting(TCOD_map_t map, int player_x, int player_y, int max_radius, bool light_walls);
 void TCOD_map_postproc(map_t *map,int x0,int y0, int x1, int y1, int dx, int dy);
 
+#ifdef TCOD_CONSOLE_SUPPORT
 /* TCODConsole non public methods*/
 bool TCOD_console_init(TCOD_console_t con,const char *title, bool fullscreen);
 int TCOD_console_print_internal(TCOD_console_t con,int x,int y, int w, int h, TCOD_bkgnd_flag_t flag, TCOD_alignment_t align, char *msg, bool can_split, bool count_only);
 int TCOD_console_stringLength(const unsigned char *s);
 unsigned char * TCOD_console_forward(unsigned char *s,int l);
 char *TCOD_console_vsprint(const char *fmt, va_list ap);
-TCOD_render_state_t *TCOD_console_get_render_state(TCOD_console_t con);
+#endif
+
 /* fatal errors */
 void TCOD_fatal(const char *fmt, ...);
 void TCOD_fatal_nopar(const char *msg);
 
 /* TCODSystem non public methods */
-bool TCOD_sys_init(int w,int h, TCOD_render_state_t *render_state, bool fullscreen);
+#ifdef TCOD_CONSOLE_SUPPORT
+bool TCOD_sys_init(TCOD_console_data_t *console, bool fullscreen);
 void TCOD_sys_uninit(void);
 void TCOD_sys_set_custom_font(const char *font_name,int nb_ch, int nb_cv,int flags);
 void TCOD_sys_map_ascii_to_font(int asciiCode, int fontCharX, int fontCharY);
@@ -220,10 +229,13 @@ void *TCOD_sys_create_bitmap_for_console(TCOD_console_t console);
 void TCOD_sys_save_bitmap(void *bitmap, const char *filename);
 void *TCOD_sys_create_bitmap(int width, int height, TCOD_color_t *buf);
 void TCOD_sys_delete_bitmap(void *bitmap);
-void TCOD_sys_console_to_bitmap(void *bitmap, int console_width, int console_height, TCOD_render_state_t *render_state);
+void TCOD_sys_console_to_bitmap(void *bitmap, TCOD_console_data_t *console,
+                                TCOD_console_data_t *cache);
 TCODLIB_API void *TCOD_sys_get_surface(int width, int height, bool alpha);
 void TCOD_sys_save_fps(void);
 void TCOD_sys_restore_fps(void);
+void TCOD_sys_set_dirty(int dx, int dy, int dw, int dh);
+void TCOD_sys_set_dirty_character_code(int ch);
 
 /* switch fullscreen mode */
 void TCOD_sys_set_fullscreen(bool fullscreen);
@@ -236,6 +248,7 @@ TCOD_key_t TCOD_sys_check_for_keypress(int flags);
 TCOD_key_t TCOD_sys_wait_for_keypress(bool flush);
 bool TCOD_sys_is_key_pressed(TCOD_keycode_t key);
 void TCOD_sys_set_window_title(const char *title);
+#endif
 
 /* UTF-8 stuff */
 #ifndef NO_UNICODE
@@ -244,30 +257,36 @@ int TCOD_console_print_internal_utf(TCOD_console_t con,int x,int y, int rw, int
 	TCOD_alignment_t align, wchar_t *msg, bool can_split, bool count_only);
 #endif
 
+#ifdef TCOD_IMAGE_SUPPORT
 /* image manipulation */
 TCODLIB_API void *TCOD_sys_load_image(const char *filename);
 void TCOD_sys_get_image_size(const void *image, int *w,int *h);
 TCOD_color_t TCOD_sys_get_image_pixel(const void *image,int x, int y);
 int TCOD_sys_get_image_alpha(const void *image,int x, int y);
-bool TCOD_sys_check_magic_number(const char *filename, int size, uint8 *data);
+bool TCOD_sys_check_magic_number(const char *filename, size_t size, uint8_t *data);
+#endif
 
 /* TCOD_list nonpublic methods */
 void TCOD_list_set_size(TCOD_list_t l, int size);
 
+#ifdef TCOD_SDL2
 /*
 	SDL12/SDL2 abstraction layer
 */
-typedef struct {
+typedef struct TCOD_SDL_driver_t {
+    float scale_xc;
+    float scale_yc;
+
 	/* get a fullscreen mode suitable for the console */
 	void (*get_closest_mode)(int *w, int *h);
 	/* render the console on a surface/texture */
-	void (*render)(void *vbitmap, int console_width, int console_height, TCOD_render_state_t *render_state);
+	void (*render)(struct TCOD_SDL_driver_t *sdl, void *vbitmap, TCOD_console_data_t *console);
 	/* create a new surface */
 	SDL_Surface *(*create_surface) (int width, int height, bool with_alpha);
 	/* create the game window */
 	void (*create_window)(int w, int h, bool fullscreen);
 	/* destroy the game window */
-	void (*destroy_window)();
+	void (*destroy_window)(void);
 	/* switch fullscreen on/off */
 	void (*set_fullscreen)(bool fullscreen);
 	/* change the game window title */
@@ -279,25 +298,23 @@ typedef struct {
 	/* change the mouse cursor position */
 	void (*set_mouse_position)(int x, int y);
 	/* clipboard */
-	char *(*get_clipboard_text)();
-	bool (*set_clipboard_text)(char *text);
+	char *(*get_clipboard_text)(void);
+	bool (*set_clipboard_text)(const char *text);
 	/* android compatible file access functions */
 	bool (*file_read)(const char *filename, unsigned char **buf, size_t *size);
 	bool (*file_exists)(const char * filename);
-	bool (*file_write)(const char *filename, unsigned char *buf, uint32 size);
+	bool (*file_write)(const char *filename, unsigned char *buf, uint32_t size);
 	/* clean stuff */
 	void (*shutdown)(void);
+	/* get root cache */
+	TCOD_console_data_t *(*get_root_console_cache)(void);
 } TCOD_SDL_driver_t;
 
 /* defined in TCOD_sys_sdl12_c.c and TCOD_sys_sdl2_c.c */
 TCOD_SDL_driver_t *SDL_implementation_factory(void);
+
 void find_resolution(void);
 void TCOD_sys_init_screen_offset(void);
-extern SDL_Surface* screen;
-extern int oldFade;
-extern bool *ascii_updated;
-extern bool any_ascii_updated;
-extern SDL_Surface* charmap;
 typedef struct {
 	float force_recalc;
 	float last_scale_xc, last_scale_yc;
@@ -316,13 +333,17 @@ typedef struct {
 	int surface_width, surface_height;
 } scale_data_t;
 extern scale_data_t scale_data;
-#ifdef TCOD_SDL2
+
 extern float scale_factor;
+extern SDL_Surface* charmap;
 extern SDL_Window* window;
 extern SDL_Renderer* renderer;
 extern char *last_clipboard_text;
 #endif
 
+/* SDL & OpenGL */
+extern int oldFade;
+
 /* color values */
 #define TCOD_BLACK 0,0,0
 #define TCOD_DARKEST_GREY 31,31,31
