@@ -1,5 +1,5 @@
 /*
-* libtcod 1.6.3
+* libtcod 1.6.4
 * Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
@@ -29,6 +29,10 @@
 #define _TCOD_TEXT_HPP_
 
 #include "color.hpp"
+#include "console.hpp"
+#include "txtfield.h"
+
+#ifdef TCOD_CONSOLE_SUPPORT
 
 class TCODLIB_API TCODText {
 public :
@@ -46,5 +50,6 @@ protected :
 	TCOD_text_t data;
 };
 
+#endif /* TCOD_CONSOLE_SUPPORT */
 
 #endif
