@@ -1,5 +1,5 @@
 /*
-* libtcod 1.6.3
+* libtcod 1.6.4
 * Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
@@ -25,18 +25,26 @@
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
+#include <console.h>
+
 #include <stdio.h>
 #include <stdarg.h>
 #include <string.h>
 #include <stdlib.h>
 #include <ctype.h>
-#include "libtcod.h"
-#include "libtcod_int.h"
 #ifndef NO_UNICODE
 #include <wchar.h>
 #include <wctype.h>
 #endif
 
+#include <noise.h>
+#include <mersenne.h>
+#include <libtcod_int.h>
+#include <libtcod_utility.h>
+#include <libtcod_version.h>
+
+#ifdef TCOD_CONSOLE_SUPPORT
+
 #if defined( TCOD_VISUAL_STUDIO )
 static const char *version_string ="libtcod "TCOD_STRVERSION;
 #else
@@ -52,9 +60,11 @@ TCOD_internal_context_t TCOD_ctx={
 	8,8,
 	"terminal.png","",
 	NULL,NULL,NULL,0,false,0,0,0,0,0,0,
+#ifdef TCOD_SDL2
 	/* default renderer to use */
 	TCOD_RENDERER_GLSL,
 	NULL,
+#endif
 	/* fading data */
 	{0,0,0},255,
 	/*key state*/
@@ -76,23 +86,6 @@ void TCOD_console_set_color_control(TCOD_colctrl_t con, TCOD_color_t fore, TCOD_
 	color_control_back[con-1]=back;
 }
 
-void TCOD_fatal(const char *fmt, ...) {
-	va_list ap;
-	TCOD_sys_shutdown();
-	printf("%s\n",version_string);
-	va_start(ap,fmt);
-	vprintf(fmt,ap);
-	va_end(ap);
-	printf ("\n");
-	exit (1);
-}
-
-void TCOD_fatal_nopar(const char *msg) {
-	TCOD_sys_shutdown();
-	printf("%s\n%s\n",version_string,msg);
-	exit (1);
-}
-
 TCOD_console_t TCOD_console_new(int w, int h)  {
 	TCOD_IFNOT(w > 0 && h > 0 ) {
 		return NULL;
@@ -125,9 +118,11 @@ bool TCOD_console_has_mouse_focus(void) {
 	return TCOD_ctx.app_has_mouse_focus;
 }
 
+#ifdef TCOD_SDL2
 bool TCOD_console_is_active(void) {
 	return TCOD_ctx.app_is_active;
 }
+#endif
 
 void TCOD_console_set_window_title(const char *title) {
 	TCOD_sys_set_window_title(title);
@@ -168,12 +163,9 @@ TCOD_alignment_t TCOD_console_get_alignment(TCOD_console_t con) {
 }
 
 static void TCOD_console_data_free(TCOD_console_data_t *dat) {
-	if (dat->state.fg_colors) TCOD_image_delete(dat->state.fg_colors);
-	if (dat->state.fg_colors_prev) TCOD_image_delete(dat->state.fg_colors_prev);
-	if (dat->state.bg_colors) TCOD_image_delete(dat->state.bg_colors);
-	if (dat->state.bg_colors_prev) TCOD_image_delete(dat->state.bg_colors_prev);
-	free(dat->state.buf);
-	free(dat->state.oldbuf);
+	if (dat->fg_colors) TCOD_image_delete(dat->fg_colors);
+	if (dat->bg_colors) TCOD_image_delete(dat->bg_colors);
+	free(dat->ch_array);
 }
 
 void TCOD_console_delete(TCOD_console_t con) {
@@ -199,11 +191,11 @@ void TCOD_console_blit(TCOD_console_t srcCon, int xSrc, int ySrc, int wSrc, int
 	if (hSrc == 0) hSrc = src->h;
 	TCOD_IFNOT(wSrc > 0 && hSrc > 0) return;
 	TCOD_IFNOT(xDst + wSrc >= 0 && yDst + hSrc >= 0 && xDst < dst->w && yDst < dst->h) return;
-	TCOD_image_get_key_data(src->state.bg_colors, &srcHasKeyColor, &srcKeyColor);
-	srcFgColors = TCOD_image_get_colors(src->state.fg_colors);
-	srcBgColors = TCOD_image_get_colors(src->state.bg_colors);
-	dstFgColors = TCOD_image_get_colors(dst->state.fg_colors);
-	dstBgColors = TCOD_image_get_colors(dst->state.bg_colors);
+	TCOD_image_get_key_data(src->bg_colors, &srcHasKeyColor, &srcKeyColor);
+	srcFgColors = TCOD_image_get_colors(src->fg_colors);
+	srcBgColors = TCOD_image_get_colors(src->bg_colors);
+	dstFgColors = TCOD_image_get_colors(dst->fg_colors);
+	dstBgColors = TCOD_image_get_colors(dst->bg_colors);
 	for (cx = xSrc; cx < xSrc + wSrc; cx++) {
 		for (cy = ySrc; cy < ySrc + hSrc; cy++) {
 			/* check if we're outside the dest console */
@@ -211,13 +203,11 @@ void TCOD_console_blit(TCOD_console_t srcCon, int xSrc, int ySrc, int wSrc, int
 			int dy = cy - ySrc + yDst;
 			int dst_idx = dy * dst->w + dx;
 			int src_idx = cy * src->w + cx;
-			uint8 dirty;
-			char_t srcChar, dstChar;
+			int srcChar, dstChar;
 			TCOD_color_t srcFgColor, srcBgColor, dstFgColor, dstBgColor;
 			if ((unsigned)cx >= (unsigned)src->w || (unsigned)cy >= (unsigned)src->h) continue;
 			if ((unsigned)dx >= (unsigned)dst->w || (unsigned)dy >= (unsigned)dst->h) continue;
-			dirty = dst->state.buf[dst_idx].dirty;
-			srcChar = src->state.buf[src_idx];
+			srcChar = src->ch_array[src_idx];
 			srcFgColor = srcFgColors[src_idx];
 			srcBgColor = srcBgColors[src_idx];
 			/* check if source pixel is transparent */
@@ -231,20 +221,19 @@ void TCOD_console_blit(TCOD_console_t srcCon, int xSrc, int ySrc, int wSrc, int
 				dstBgColor = srcBgColor;
 			}
 			else {
-				dstChar = dst->state.buf[dst_idx];
+				dstChar = dst->ch_array[dst_idx];
 				dstFgColor = dstFgColors[dst_idx];
 				dstBgColor = dstBgColors[dst_idx];
 
 				dstBgColor = TCOD_color_lerp(dstBgColor, srcBgColor, background_alpha);
-				if (srcChar.c == ' ') {
+				if (srcChar == ' ') {
 					dstFgColor = TCOD_color_lerp(dstFgColor, srcBgColor, background_alpha);
 				}
-				else if (dstChar.c == ' ') {
-					dstChar.c = srcChar.c;
-					dstChar.cf = srcChar.cf;
+				else if (dstChar == ' ') {
+					dstChar = srcChar;
 					dstFgColor = TCOD_color_lerp(dstBgColor, srcFgColor, foreground_alpha);
 				}
-				else if (dstChar.c == srcChar.c) {
+				else if (dstChar == srcChar) {
 					dstFgColor = TCOD_color_lerp(dstFgColor, srcFgColor, foreground_alpha);
 				}
 				else {
@@ -253,8 +242,7 @@ void TCOD_console_blit(TCOD_console_t srcCon, int xSrc, int ySrc, int wSrc, int
 							foreground_alpha * 2);
 					}
 					else {
-						dstChar.c = srcChar.c;
-						dstChar.cf = srcChar.cf;
+						dstChar = srcChar;
 						dstFgColor = TCOD_color_lerp(dstBgColor, srcFgColor,
 							(foreground_alpha - 0.5f) * 2);
 					}
@@ -262,29 +250,24 @@ void TCOD_console_blit(TCOD_console_t srcCon, int xSrc, int ySrc, int wSrc, int
 			}
 			dstFgColors[dst_idx] = dstFgColor;
 			dstBgColors[dst_idx] = dstBgColor;
-			dst->state.buf[dst_idx] = dstChar;
-			dst->state.buf[dst_idx].dirty = dirty;
+			dst->ch_array[dst_idx] = dstChar;
 		}
 	}
-	TCOD_image_invalidate_mipmaps(dst->state.fg_colors);
-	TCOD_image_invalidate_mipmaps(dst->state.bg_colors);
+	TCOD_image_invalidate_mipmaps(dst->fg_colors);
+	TCOD_image_invalidate_mipmaps(dst->bg_colors);
 }
 
 void TCOD_console_flush(void) {
-	TCOD_console_data_t *dat = TCOD_ctx.root;
 	TCOD_IFNOT(TCOD_ctx.root != NULL) return;
 	TCOD_sys_flush(true);
-	memcpy(dat->state.oldbuf, dat->state.buf, sizeof(char_t)*dat->w*dat->h);
-	TCOD_image_mipmap_copy_internal(dat->state.fg_colors, dat->state.fg_colors_prev);
-	TCOD_image_mipmap_copy_internal(dat->state.bg_colors, dat->state.bg_colors_prev);
 }
 
-void TCOD_console_set_fade(uint8 val, TCOD_color_t fadecol) {
+void TCOD_console_set_fade(uint8_t val, TCOD_color_t fadecol) {
 	TCOD_ctx.fade=val;
 	TCOD_ctx.fading_color=fadecol;
 }
 
-uint8 TCOD_console_get_fade(void) {
+uint8_t TCOD_console_get_fade(void) {
 	return TCOD_ctx.fade;
 }
 
@@ -298,9 +281,8 @@ void TCOD_console_put_char(TCOD_console_t con, int x, int y, int c, TCOD_bkgnd_f
 	TCOD_IFNOT(dat != NULL && (unsigned)(x) < (unsigned)dat->w && (unsigned)(y) < (unsigned)dat->h) return;
 	TCOD_IFNOT(c >= 0 && c < TCOD_ctx.max_font_chars) return;
 	offset = y * dat->w + x;
-	dat->state.buf[offset].c = c;
-	dat->state.buf[offset].cf = TCOD_ctx.ascii_to_tcod[c];
-	TCOD_image_put_pixel(dat->state.fg_colors, x, y, dat->fore);
+	dat->ch_array[offset] = c;
+	TCOD_image_put_pixel(dat->fg_colors, x, y, dat->fore);
 	TCOD_console_set_char_background(con, x, y, dat->back, (TCOD_bkgnd_flag_t)flag);
 }
 
@@ -310,50 +292,26 @@ void TCOD_console_put_char_ex(TCOD_console_t con, int x, int y, int c, TCOD_colo
 	TCOD_IFNOT(dat != NULL && (unsigned)(x) < (unsigned)dat->w && (unsigned)(y) < (unsigned)dat->h) return;
 	TCOD_IFNOT(c >= 0 && c < TCOD_ctx.max_font_chars) return;
 	offset = y * dat->w + x;
-	dat->state.buf[offset].c = c;
-	dat->state.buf[offset].cf = TCOD_ctx.ascii_to_tcod[c];
-	TCOD_image_put_pixel(dat->state.fg_colors, x, y, fore);
-	TCOD_image_put_pixel(dat->state.bg_colors, x, y, back);
+	dat->ch_array[offset] = c;
+	TCOD_image_put_pixel(dat->fg_colors, x, y, fore);
+	TCOD_image_put_pixel(dat->bg_colors, x, y, back);
 }
 
 void TCOD_console_set_dirty(int dx, int dy, int dw, int dh) {
-	int x, y;
-	TCOD_console_data_t *dat = TCOD_ctx.root;
-	TCOD_IFNOT(dat != NULL) return;
-	TCOD_IFNOT(dx < dat->w && dy < dat->h && dx + dw >= 0 && dy + dh >= 0) return;
-	TCOD_IFNOT(dx >= 0) {
-		dw += dx;
-		dx = 0;
-	}
-	TCOD_IFNOT(dy >= 0) {
-		dh += dy;
-		dy = 0;
-	}
-	TCOD_IFNOT(dx + dw <= dat->w) dw = dat->w - dx;
-	TCOD_IFNOT(dy + dh <= dat->h) dh = dat->h - dy;
-
-	for (x = dx; x < dx + dw; x++) {
-		for (y = dy; y < dy + dh; y++) {
-			int off = x + dat->w*y;
-			dat->state.buf[off].dirty = 1;
-		}
-	}
+	TCOD_sys_set_dirty(dx, dy, dw, dh);
 }
 
 void TCOD_console_clear(TCOD_console_t con) {
-	int x, y;
+	int i;
 	TCOD_console_data_t *dat = con ? (TCOD_console_data_t *)con : TCOD_ctx.root;
 	TCOD_IFNOT(dat != NULL) return;
-	for (x = 0; x < dat->w; x++) {
-		for (y = 0; y < dat->h; y++) {
-			int off = x + dat->w*y;
-			dat->state.buf[off].dirty = 0;
-			dat->state.buf[off].c = ' ';
-			dat->state.buf[off].cf = TCOD_ctx.ascii_to_tcod ? TCOD_ctx.ascii_to_tcod[' '] : 0;
-		}
+	for (i = 0; i < dat->w * dat->h; i++) {
+		dat->ch_array[i] = ' ';
 	}
-	TCOD_image_clear(dat->state.fg_colors, dat->fore);
-	TCOD_image_clear(dat->state.bg_colors, dat->back);
+	TCOD_image_clear(dat->fg_colors, dat->fore);
+	TCOD_image_clear(dat->bg_colors, dat->back);
+	/* clear the sdl renderer cache */
+	TCOD_sys_set_dirty(0, 0, dat->w, dat->h);
 }
 
 TCOD_color_t TCOD_console_get_char_background(TCOD_console_t con, int x, int y) {
@@ -361,7 +319,7 @@ TCOD_color_t TCOD_console_get_char_background(TCOD_console_t con, int x, int y)
 	TCOD_IFNOT(dat != NULL
 		&& (unsigned)(x) < (unsigned)dat->w && (unsigned)(y) < (unsigned)dat->h)
 		return TCOD_black;
-	return TCOD_image_get_pixel(dat->state.bg_colors, x, y);
+	return TCOD_image_get_pixel(dat->bg_colors, x, y);
 }
 
 void TCOD_console_set_char_foreground(TCOD_console_t con, int x, int y, TCOD_color_t col) {
@@ -370,7 +328,7 @@ void TCOD_console_set_char_foreground(TCOD_console_t con, int x, int y, TCOD_col
 	TCOD_IFNOT(dat != NULL
 		&& (unsigned)(x) < (unsigned)dat->w && (unsigned)(y) < (unsigned)dat->h)
 		return;
-	TCOD_image_put_pixel(dat->state.fg_colors, x, y, col);
+	TCOD_image_put_pixel(dat->fg_colors, x, y, col);
 }
 
 TCOD_color_t TCOD_console_get_char_foreground(TCOD_console_t con, int x, int y) {
@@ -378,7 +336,7 @@ TCOD_color_t TCOD_console_get_char_foreground(TCOD_console_t con, int x, int y)
 	TCOD_IFNOT(dat != NULL
 		&& (unsigned)(x) < (unsigned)dat->w && (unsigned)(y) < (unsigned)dat->h)
 		return TCOD_white;
-	return TCOD_image_get_pixel(dat->state.fg_colors, x, y);
+	return TCOD_image_get_pixel(dat->fg_colors, x, y);
 }
 
 int TCOD_console_get_char(TCOD_console_t con, int x, int y) {
@@ -386,7 +344,7 @@ int TCOD_console_get_char(TCOD_console_t con, int x, int y) {
 	TCOD_IFNOT(dat != NULL
 		&& (unsigned)(x) < (unsigned)dat->w && (unsigned)(y) < (unsigned)dat->h)
 		return 0;
-	return dat->state.buf[y * dat->w + x].c;
+	return dat->ch_array[y * dat->w + x];
 }
 
 void TCOD_console_set_char_background(TCOD_console_t con, int x, int y, TCOD_color_t col, TCOD_bkgnd_flag_t flag) {
@@ -397,7 +355,7 @@ void TCOD_console_set_char_background(TCOD_console_t con, int x, int y, TCOD_col
 	TCOD_IFNOT(dat != NULL
 		&& (unsigned)(x) < (unsigned)dat->w && (unsigned)(y) < (unsigned)dat->h)
 		return;
-	back = &(TCOD_image_get_colors(dat->state.bg_colors)[y*dat->w + x]);
+	back = &(TCOD_image_get_colors(dat->bg_colors)[y*dat->w + x]);
 	if (flag == TCOD_BKGND_DEFAULT) flag = dat->bkgnd_flag;
 	switch (flag & 0xff) {
 	case TCOD_BKGND_SET: *back = col; break;
@@ -414,9 +372,9 @@ void TCOD_console_set_char_background(TCOD_console_t con, int x, int y, TCOD_col
 		break;
 	case TCOD_BKGND_SCREEN:
 		/* newbk = white - (white - oldbk) * (white - curbk) */
-		back->r = (uint8)(255 - (int)(255 - back->r)*(255 - col.r) / 255);
-		back->g = (uint8)(255 - (int)(255 - back->g)*(255 - col.g) / 255);
-		back->b = (uint8)(255 - (int)(255 - back->b)*(255 - col.b) / 255);
+		back->r = (uint8_t)(255 - (int)(255 - back->r)*(255 - col.r) / 255);
+		back->g = (uint8_t)(255 - (int)(255 - back->g)*(255 - col.g) / 255);
+		back->b = (uint8_t)(255 - (int)(255 - back->b)*(255 - col.b) / 255);
 		break;
 	case TCOD_BKGND_COLOR_DODGE:
 		/* newbk = curbk / (white - oldbk) */
@@ -426,9 +384,9 @@ void TCOD_console_set_char_background(TCOD_console_t con, int x, int y, TCOD_col
 		else newg = 255;
 		if (back->b != 255) newb = (int)(255 * col.b) / (255 - back->b);
 		else newb = 255;
-		back->r = (uint8)CLAMP(0, 255, newr);
-		back->g = (uint8)CLAMP(0, 255, newg);
-		back->b = (uint8)CLAMP(0, 255, newb);
+		back->r = (uint8_t)CLAMP(0, 255, newr);
+		back->g = (uint8_t)CLAMP(0, 255, newg);
+		back->b = (uint8_t)CLAMP(0, 255, newb);
 		break;
 	case TCOD_BKGND_COLOR_BURN:
 		/* newbk = white - (white - oldbk) / curbk */
@@ -438,18 +396,18 @@ void TCOD_console_set_char_background(TCOD_console_t con, int x, int y, TCOD_col
 		else newg = 0;
 		if (col.b > 0) newb = 255 - (int)(255 * (255 - back->b)) / col.b;
 		else newb = 0;
-		back->r = (uint8)CLAMP(0, 255, newr);
-		back->g = (uint8)CLAMP(0, 255, newg);
-		back->b = (uint8)CLAMP(0, 255, newb);
+		back->r = (uint8_t)CLAMP(0, 255, newr);
+		back->g = (uint8_t)CLAMP(0, 255, newg);
+		back->b = (uint8_t)CLAMP(0, 255, newb);
 		break;
 	case TCOD_BKGND_ADD:
 		/* newbk = oldbk + curbk */
 		newr = (int)(back->r) + col.r;
 		newg = (int)(back->g) + col.g;
 		newb = (int)(back->b) + col.b;
-		back->r = (uint8)CLAMP(0, 255, newr);
-		back->g = (uint8)CLAMP(0, 255, newg);
-		back->b = (uint8)CLAMP(0, 255, newb);
+		back->r = (uint8_t)CLAMP(0, 255, newr);
+		back->g = (uint8_t)CLAMP(0, 255, newg);
+		back->b = (uint8_t)CLAMP(0, 255, newb);
 		break;
 	case TCOD_BKGND_ADDA:
 		alpha = (flag >> 8);
@@ -457,27 +415,27 @@ void TCOD_console_set_char_background(TCOD_console_t con, int x, int y, TCOD_col
 		newr = (int)(back->r) + alpha * col.r / 255;
 		newg = (int)(back->g) + alpha * col.g / 255;
 		newb = (int)(back->b) + alpha * col.b / 255;
-		back->r = (uint8)CLAMP(0, 255, newr);
-		back->g = (uint8)CLAMP(0, 255, newg);
-		back->b = (uint8)CLAMP(0, 255, newb);
+		back->r = (uint8_t)CLAMP(0, 255, newr);
+		back->g = (uint8_t)CLAMP(0, 255, newg);
+		back->b = (uint8_t)CLAMP(0, 255, newb);
 		break;
 	case TCOD_BKGND_BURN:
 		/* newbk = oldbk + curbk - white */
 		newr = (int)(back->r) + col.r - 255;
 		newg = (int)(back->g) + col.g - 255;
 		newb = (int)(back->b) + col.b - 255;
-		back->r = (uint8)CLAMP(0, 255, newr);
-		back->g = (uint8)CLAMP(0, 255, newg);
-		back->b = (uint8)CLAMP(0, 255, newb);
+		back->r = (uint8_t)CLAMP(0, 255, newr);
+		back->g = (uint8_t)CLAMP(0, 255, newg);
+		back->b = (uint8_t)CLAMP(0, 255, newb);
 		break;
 	case TCOD_BKGND_OVERLAY:
 		/* newbk = curbk.x <= 0.5 ? 2*curbk*oldbk : white - 2*(white-curbk)*(white-oldbk) */
 		newr = col.r <= 128 ? 2 * (int)(col.r) * back->r / 255 : 255 - 2 * (int)(255 - col.r)*(255 - back->r) / 255;
 		newg = col.g <= 128 ? 2 * (int)(col.g) * back->g / 255 : 255 - 2 * (int)(255 - col.g)*(255 - back->g) / 255;
 		newb = col.b <= 128 ? 2 * (int)(col.b) * back->b / 255 : 255 - 2 * (int)(255 - col.b)*(255 - back->b) / 255;
-		back->r = (uint8)CLAMP(0, 255, newr);
-		back->g = (uint8)CLAMP(0, 255, newg);
-		back->b = (uint8)CLAMP(0, 255, newb);
+		back->r = (uint8_t)CLAMP(0, 255, newr);
+		back->g = (uint8_t)CLAMP(0, 255, newg);
+		back->b = (uint8_t)CLAMP(0, 255, newb);
 		break;
 	case TCOD_BKGND_ALPH:
 		/* newbk = (1.0f-alpha)*oldbk + alpha*(curbk-oldbk) */
@@ -491,8 +449,7 @@ void TCOD_console_set_char_background(TCOD_console_t con, int x, int y, TCOD_col
 void TCOD_console_set_char(TCOD_console_t con, int x, int y, int c) {
 	TCOD_console_data_t *dat = con ? (TCOD_console_data_t *)con : TCOD_ctx.root;
 	if ((unsigned)(x) >= (unsigned)dat->w || (unsigned)(y) >= (unsigned)dat->h) return;
-	dat->state.buf[y * dat->w + x].c = c;
-	dat->state.buf[y * dat->w + x].cf = TCOD_ctx.ascii_to_tcod[c];
+	dat->ch_array[y * dat->w + x] = c;
 }
 
 static void TCOD_console_clamp(int cx, int cy, int cw, int ch, int *x, int *y, int *w, int *h) {
@@ -521,8 +478,7 @@ void TCOD_console_rect(TCOD_console_t con, int x, int y, int rw, int rh, bool cl
 		for (cy = y; cy<y + rh; cy++) {
 			TCOD_console_set_char_background(con, cx, cy, dat->back, flag);
 			if (clear) {
-				dat->state.buf[cx + cy*dat->w].c = ' ';
-				dat->state.buf[cx + cy*dat->w].cf = TCOD_ctx.ascii_to_tcod[' '];
+				dat->ch_array[cx + cy*dat->w] = ' ';
 			}
 		}
 	}
@@ -984,14 +940,14 @@ int TCOD_console_print_internal_utf(TCOD_console_t con,int x,int y, int rw, int
 					dat->back=color_control_back[(int)(*c)-1];
 				} else if ( *c == TCOD_COLCTRL_FORE_RGB ) {
 					c++;
-					dat->fore.r=(uint8)(*c++);
-					dat->fore.g=(uint8)(*c++);
-					dat->fore.b=(uint8)(*c);
+					dat->fore.r=(uint8_t)(*c++);
+					dat->fore.g=(uint8_t)(*c++);
+					dat->fore.b=(uint8_t)(*c);
 				} else if ( *c == TCOD_COLCTRL_BACK_RGB ) {
 					c++;
-					dat->back.r=(uint8)(*c++);
-					dat->back.g=(uint8)(*c++);
-					dat->back.b=(uint8)(*c);
+					dat->back.r=(uint8_t)(*c++);
+					dat->back.g=(uint8_t)(*c++);
+					dat->back.b=(uint8_t)(*c);
 				} else if ( *c == TCOD_COLCTRL_STOP ) {
 					dat->fore=oldFore;
 					dat->back=oldBack;
@@ -1077,7 +1033,9 @@ void TCOD_console_init_root(int w, int h, const char*title, bool fullscreen, TCO
 		con->w=w;
 		con->h=h;
 		TCOD_ctx.root=con;
+#ifdef TCOD_SDL2
 		TCOD_ctx.renderer=renderer;
+#endif
 		for (i=0; i < TCOD_COLCTRL_NUMBER; i++) {
 			color_control_fore[i]=TCOD_white;
 			color_control_back[i]=TCOD_black;
@@ -1087,13 +1045,9 @@ void TCOD_console_init_root(int w, int h, const char*title, bool fullscreen, TCO
 }
 
 static void TCOD_console_data_alloc(TCOD_console_data_t *dat) {
-	dat->state.buf = (char_t *)calloc(sizeof(char_t), dat->w*dat->h);
-	dat->state.oldbuf = (char_t *)calloc(sizeof(char_t), dat->w*dat->h);
-	dat->state.fg_colors = TCOD_image_new(dat->w, dat->h);
-	dat->state.fg_colors_prev = TCOD_image_new(dat->w, dat->h);
-	dat->state.bg_colors = TCOD_image_new(dat->w, dat->h);
-	dat->state.bg_colors_prev = TCOD_image_new(dat->w, dat->h);
-	dat->state.clear_screen = false;
+	dat->ch_array = (int *)calloc(sizeof(int), dat->w*dat->h);
+	dat->fg_colors = TCOD_image_new(dat->w, dat->h);
+	dat->bg_colors = TCOD_image_new(dat->w, dat->h);
 }
 
 bool TCOD_console_init(TCOD_console_t con,const char *title, bool fullscreen) {
@@ -1102,18 +1056,16 @@ bool TCOD_console_init(TCOD_console_t con,const char *title, bool fullscreen) {
 	TCOD_IFNOT(dat != NULL) return false;
 	dat->fore=TCOD_white;
 	dat->back=TCOD_black;
-	dat->fade=255;
 
 	TCOD_console_data_alloc(dat);
 
 	dat->bkgnd_flag=TCOD_BKGND_NONE;
 	dat->alignment=TCOD_LEFT;
 	for (i=0; i< dat->w*dat->h; i++) {
-		dat->state.buf[i].c=' ';
-		dat->state.buf[i].cf=-1;
+		dat->ch_array[i] = ' ';
 	}
 	if ( title ) {
-		if (! TCOD_sys_init(dat->w,dat->h,&dat->state,fullscreen) ) return false;
+		if (! TCOD_sys_init(dat, fullscreen) ) return false;
 		TCOD_sys_set_window_title(title);
 	}
 	return true;
@@ -1158,19 +1110,13 @@ int TCOD_console_get_height(TCOD_console_t con) {
 TCOD_image_t TCOD_console_get_foreground_color_image(TCOD_console_t con) {
 	TCOD_console_data_t *dat = con ? (TCOD_console_data_t *)con : TCOD_ctx.root;
 	TCOD_IFNOT(dat != NULL) return NULL;
-	return dat->state.fg_colors;
+	return dat->fg_colors;
 }
 
 TCOD_image_t TCOD_console_get_background_color_image(TCOD_console_t con) {
 	TCOD_console_data_t *dat = con ? (TCOD_console_data_t *)con : TCOD_ctx.root;
 	TCOD_IFNOT(dat != NULL) return NULL;
-	return dat->state.bg_colors;
-}
-
-TCOD_render_state_t *TCOD_console_get_render_state(TCOD_console_t con) {
-	TCOD_console_data_t *dat=con ? (TCOD_console_data_t *)con : TCOD_ctx.root;
-	TCOD_IFNOT(dat != NULL) return NULL;
-	return &dat->state;
+	return dat->bg_colors;
 }
 
 void TCOD_console_set_custom_font(const char *fontFile, int flags,int nb_char_horiz, int nb_char_vertic) {
@@ -1219,7 +1165,7 @@ bool TCOD_console_is_key_pressed(TCOD_keycode_t key) {
 void TCOD_console_set_key_color(TCOD_console_t con,TCOD_color_t col) {
 	TCOD_console_data_t *dat=con ? (TCOD_console_data_t *)con : TCOD_ctx.root;
 	TCOD_IFNOT(dat != NULL) return;
-	TCOD_image_set_key_color(dat->state.bg_colors, col);
+	TCOD_image_set_key_color(dat->bg_colors, col);
 }
 
 void TCOD_console_credits(void) {
@@ -1523,6 +1469,14 @@ static void TCOD_console_read_asc(TCOD_console_t con,FILE *f,int width, int heig
 static void TCOD_console_read_apf(TCOD_console_t con,FILE *f,int width, int height, float version) {
 }
 
+static int string_ends_with(const char *str, const char *suffix) {
+	size_t str_len = strlen(str);
+	size_t suffix_len = strlen(suffix);
+	return
+		(str_len >= suffix_len) &&
+		(0 == strcmp(str + (str_len-suffix_len), suffix));
+}
+
 TCOD_console_t TCOD_console_from_file(const char *filename) {
 	float version;
 	int width,height;
@@ -1531,6 +1485,9 @@ TCOD_console_t TCOD_console_from_file(const char *filename) {
 	TCOD_IFNOT( filename != NULL ) {
 		return NULL;
 	}
+	if (string_ends_with(filename, ".xp")) {
+		return TCOD_console_from_xp(filename);
+	}
 	f=fopen(filename,"rb");
 	TCOD_IFNOT( f!=NULL ) {
 		return NULL;
@@ -1548,9 +1505,11 @@ TCOD_console_t TCOD_console_from_file(const char *filename) {
 		return NULL;
 	}
 	con=TCOD_console_new(width,height);
-	if ( strstr(filename,".asc") )
+	if (string_ends_with(filename, ".asc")) {
 		TCOD_console_read_asc(con,f,width,height,version);
-	else TCOD_console_read_apf(con,f,width,height,version);
+	} else {
+		TCOD_console_read_apf(con,f,width,height,version);
+	}
 	return con;
 }
 
@@ -1630,8 +1589,8 @@ static bool hasDetectedBigEndianness = false;
 static bool isBigEndian;
 void detectBigEndianness(void) {
 	if (!hasDetectedBigEndianness){
-		uint32 Value32;
-		uint8 *VPtr = (uint8 *)&Value32;
+		uint32_t Value32;
+		uint8_t *VPtr = (uint8_t *)&Value32;
 		VPtr[0] = VPtr[1] = VPtr[2] = 0; VPtr[3] = 1;
 		if(Value32 == 1) isBigEndian = true;
 		else isBigEndian = false;
@@ -1639,19 +1598,19 @@ void detectBigEndianness(void) {
 	}
 }
 
-uint16 bswap16(uint16 s){
-	uint8* ps = (uint8*)&s;
-	uint16 res;
-	uint8* pres = (uint8*)&res;
+uint16_t bswap16(uint16_t s){
+	uint8_t* ps = (uint8_t*)&s;
+	uint16_t res;
+	uint8_t* pres = (uint8_t*)&res;
 	pres[0] = ps[1];
 	pres[1] = ps[0];
 	return res;
 }
 
-uint32 bswap32(uint32 s){
-	uint8 *ps=(uint8 *)(&s);
-	uint32 res;
-	uint8 *pres=(uint8 *)&res;
+uint32_t bswap32(uint32_t s){
+	uint8_t *ps=(uint8_t *)(&s);
+	uint32_t res;
+	uint8_t *pres=(uint8_t *)&res;
 	pres[0]=ps[3];
 	pres[1]=ps[2];
 	pres[2]=ps[1];
@@ -1659,35 +1618,35 @@ uint32 bswap32(uint32 s){
 	return res;
 }
 
-uint16 l16(uint16 s){
+uint16_t l16(uint16_t s){
 	if (isBigEndian) return bswap16(s); else return s;
 }
 
-uint32 l32(uint32 s){
+uint32_t l32(uint32_t s){
 	if (isBigEndian) return bswap32(s); else return s;
 }
 
 /* fix the endianness */
-void fix16(uint16* u){
+void fix16(uint16_t* u){
 	*u = l16(*u);
 }
 
-void fix32(uint32* u){
+void fix32(uint32_t* u){
 	*u = l32(*u);
 }
 
 /************ RIFF helpers  */
 
-uint32 fourCC(const char* c){
-	return (*(uint32*)c);
+uint32_t fourCC(const char* c){
+	return (*(uint32_t*)c);
 }
 
 /* checks if u equals str */
-bool fourCCequals(uint32 u, const char* str){
+bool fourCCequals(uint32_t u, const char* str){
 	return fourCC(str)==u;
 }
 
-void fromFourCC(uint32 u, char*s){
+void fromFourCC(uint32_t u, char*s){
 	const char* c = (const char*)(&u);
 	s[0]=c[0];
 	s[1]=c[1];
@@ -1696,15 +1655,15 @@ void fromFourCC(uint32 u, char*s){
 	s[4]=0;
 }
 
-void put8(uint8 d, FILE* fp){
+void put8(uint8_t d, FILE* fp){
 	fwrite(&d,1,1,fp);
 }
 
-void put16(uint16 d, FILE* fp){
+void put16(uint16_t d, FILE* fp){
 	fwrite(&d,2,1,fp);
 }
 
-void put32(uint32 d, FILE* fp){
+void put32(uint32_t d, FILE* fp){
 	fwrite(&d,4,1,fp);
 }
 
@@ -1716,16 +1675,16 @@ void putData(void* what, int length, FILE* fp){
 	fwrite(what,length,1,fp);
 }
 
-bool get8(uint8* u, FILE* fp){
-	return 1==fread((void*)u, sizeof(uint8),1,fp);
+bool get8(uint8_t* u, FILE* fp){
+	return 1==fread((void*)u, sizeof(uint8_t),1,fp);
 }
 
-bool get16(uint16* u, FILE* fp){
-	return 1==fread((void*)u, sizeof(uint16),1,fp);
+bool get16(uint16_t* u, FILE* fp){
+	return 1==fread((void*)u, sizeof(uint16_t),1,fp);
 }
 
-bool get32(uint32* u, FILE* fp){
-	return 1==fread((void*)u, sizeof(uint32),1,fp);
+bool get32(uint32_t* u, FILE* fp){
+	return 1==fread((void*)u, sizeof(uint32_t),1,fp);
 }
 
 bool getData(void* u, size_t sz, FILE* fp){
@@ -1736,38 +1695,38 @@ bool getData(void* u, size_t sz, FILE* fp){
 /********* APF RIFF structures */
 
 typedef struct {
-	uint32 show_grid;
-	uint32 grid_width;
-	uint32 grid_height;
+	uint32_t show_grid;
+	uint32_t grid_width;
+	uint32_t grid_height;
 } SettingsDataV1;
 
 #define FILTER_TYPE_UNCOMPRESSED 0
 #define FORMAT_TYPE_CRGBRGB 0
 
 typedef struct {
-	uint32 width;
-	uint32 height;
-	uint32 filter;
-	uint32 format;
+	uint32_t width;
+	uint32_t height;
+	uint32_t filter;
+	uint32_t format;
 } ImageDetailsV1;
 
 /* Layers */
 
 typedef struct {
-	uint32 name;
-	uint32 mode;
-	uint32 index;
-	uint32 dataSize;
+	uint32_t name;
+	uint32_t mode;
+	uint32_t index;
+	uint32_t dataSize;
 } LayerV1 ;
 
 typedef struct {
-	uint32 name;
-	uint32 mode;
-	uint32 fgalpha;
-	uint32 bgalpha;
-	uint32 visible;
-	uint32 index;
-	uint32 dataSize;
+	uint32_t name;
+	uint32_t mode;
+	uint32_t fgalpha;
+	uint32_t bgalpha;
+	uint32_t visible;
+	uint32_t index;
+	uint32_t dataSize;
 } LayerV2;
 
 /* fix the endianness */
@@ -1814,14 +1773,14 @@ bool TCOD_console_save_apf(TCOD_console_t pcon, const char *filename) {
 	}
 	else {
 		int x,y;
-		uint32 riffSize = 0;
-		uint32 imgDetailsSize ;
+		uint32_t riffSize = 0;
+		uint32_t imgDetailsSize ;
 		SettingsDataV1 settingsData;
 		ImageDetailsV1 imgData;
 		fpos_t posRiffSize;
-		uint32 settingsSz ;
-		uint32 layerImageSize ;
-		uint32 layerChunkSize ;
+		uint32_t settingsSz ;
+		uint32_t layerImageSize ;
+		uint32_t layerChunkSize ;
 		/*  riff header*/
 		putFourCC("RIFF",fp);
 		fgetpos(fp,&posRiffSize);
@@ -1835,7 +1794,7 @@ bool TCOD_console_save_apf(TCOD_console_t pcon, const char *filename) {
 				settingsData.show_grid = 0;
 				settingsData.grid_width = 8;
 				settingsData.grid_height = 8;
-				settingsSz = sizeof(uint32) + sizeof settingsData;
+				settingsSz = sizeof(uint32_t) + sizeof settingsData;
 				putFourCC("sett",fp);
 				put32(l32(settingsSz),fp);
 				put32(l32(1),fp);
@@ -1851,7 +1810,7 @@ bool TCOD_console_save_apf(TCOD_console_t pcon, const char *filename) {
 				imgData.height = con->h;
 				imgData.filter = 0;
 				imgData.format = 0;
-				imgDetailsSize = sizeof(uint32) + sizeof imgData;
+				imgDetailsSize = sizeof(uint32_t) + sizeof imgData;
 				putFourCC("imgd",fp);
 				put32(l32(imgDetailsSize),fp);
 				put32(l32(1),fp); 
@@ -1866,7 +1825,7 @@ bool TCOD_console_save_apf(TCOD_console_t pcon, const char *filename) {
 				   the first layer is the lowest layer
 				   Assume imgData filter = uncompressed, and imgData format = CRGB */
 				layerImageSize = imgData.width*imgData.height*7;
-				layerChunkSize = sizeof(uint32) /* version */
+				layerChunkSize = sizeof(uint32_t) /* version */
 						+ sizeof(LayerV2) /* header */
 						+ layerImageSize; /* data */
 
@@ -1906,7 +1865,7 @@ bool TCOD_console_save_apf(TCOD_console_t pcon, const char *filename) {
 						riffSize++;
 					}
 
-				riffSize += 2*sizeof(uint32)+layerChunkSize;
+				riffSize += 2*sizeof(uint32_t)+layerChunkSize;
 
 		fsetpos(fp,&posRiffSize);
 		put32(l32(riffSize),fp);
@@ -1919,7 +1878,7 @@ bool TCOD_console_save_apf(TCOD_console_t pcon, const char *filename) {
 typedef struct {
 	LayerV1 headerv1;
 	LayerV2 headerv2;
-	uint8* data; /* dynamically allocated */
+	uint8_t* data; /* dynamically allocated */
 }  LayerData;
 
 typedef struct {
@@ -1929,13 +1888,13 @@ typedef struct {
 } Data;
 
 bool TCOD_console_load_apf(TCOD_console_t pcon, const char *filename) {
-	uint32 sett = fourCC("sett");
-	uint32 imgd = fourCC("imgd");
+	uint32_t sett = fourCC("sett");
+	uint32_t imgd = fourCC("imgd");
 	/*
-	uint32 LIST = fourCC("LIST");
-	uint32 LAYR = fourCC("LAYR");
+	uint32_t LIST = fourCC("LIST");
+	uint32_t LAYR = fourCC("LAYR");
 	*/
-	uint32 layr = fourCC("layr");
+	uint32_t layr = fourCC("layr");
 	FILE* fp ;
 	Data data; 
 	TCOD_console_data_t *con=pcon ? (TCOD_console_data_t *)pcon : TCOD_ctx.root;
@@ -1961,11 +1920,11 @@ bool TCOD_console_load_apf(TCOD_console_t pcon, const char *filename) {
 	}
 	else {
 		/* read the header */
-		uint32 riff;
-		uint32 riffSize;
+		uint32_t riff;
+		uint32_t riffSize;
 		int index = 0;
 		int x,y;
-		uint8 *imgData;
+		uint8_t *imgData;
 		bool keepGoing = true;
 		if (! get32(&riff,fp) || ! fourCCequals(riff,"RIFF")){
 			ERR("File doesn't have a RIFF header");
@@ -1974,12 +1933,12 @@ bool TCOD_console_load_apf(TCOD_console_t pcon, const char *filename) {
 		fix32(&riffSize);
 
 		while(keepGoing && fp){ /* for each subfield, try to find the APF_ field */
-			uint32 apf;
+			uint32_t apf;
 			if (! get32(&apf,fp)) break;
 			if (fourCCequals(apf,"apf ") || fourCCequals(apf,"APF ")){
 				/* Process APF segment */
 				while(keepGoing && fp){
-					uint32 seg;
+					uint32_t seg;
 					if (! get32(&seg,fp)){
 						keepGoing = false;
 						break;
@@ -1987,8 +1946,8 @@ bool TCOD_console_load_apf(TCOD_console_t pcon, const char *filename) {
 					else {
 						if (seg==sett){
 							/* size */
-							uint32 sz;
-							uint32 ver;
+							uint32_t sz;
+							uint32_t ver;
 							SettingsDataV1 settingsData;
 
 							get32(&sz,fp);
@@ -2005,8 +1964,8 @@ bool TCOD_console_load_apf(TCOD_console_t pcon, const char *filename) {
 						}
 						else if (seg==imgd){
 							/* sz */
-							uint32 sz;
-							uint32 ver;
+							uint32_t sz;
+							uint32_t ver;
 							ImageDetailsV1 dets;
 
 							get32(&sz,fp);
@@ -2035,8 +1994,8 @@ bool TCOD_console_load_apf(TCOD_console_t pcon, const char *filename) {
 
 						}
 						else if (seg==layr){
-							uint32 sz;
-							uint32 ver;
+							uint32_t sz;
+							uint32_t ver;
 
 							get32(&sz,fp);
 							fix32(&sz);
@@ -2050,7 +2009,7 @@ bool TCOD_console_load_apf(TCOD_console_t pcon, const char *filename) {
 								fixLayerv1(&data.layer.headerv1);
 
 								/* Read in the data chunk*/
-								data.layer.data = (uint8*)malloc(sizeof(uint8)*data.layer.headerv1.dataSize);
+								data.layer.data = (uint8_t*)malloc(sizeof(uint8_t)*data.layer.headerv1.dataSize);
 								getData((void*) data.layer.data, data.layer.headerv1.dataSize, fp);
 							}
 							else if (ver==2){
@@ -2058,14 +2017,14 @@ bool TCOD_console_load_apf(TCOD_console_t pcon, const char *filename) {
 								fixLayerv2(&data.layer.headerv2);
 
 								/* Read in the data chunk */
-								data.layer.data = (uint8*)malloc(sizeof(uint8)*data.layer.headerv2.dataSize);
+								data.layer.data = (uint8_t*)malloc(sizeof(uint8_t)*data.layer.headerv2.dataSize);
 								getData((void*) data.layer.data, data.layer.headerv2.dataSize, fp);
 
 							}
 						}
 						else {
 							/* skip unknown segment */
-							uint32 sz;
+							uint32_t sz;
 							get32(&sz,fp);
 							fix32(&sz);
 							fseek(fp,sz,SEEK_CUR);
@@ -2078,7 +2037,7 @@ bool TCOD_console_load_apf(TCOD_console_t pcon, const char *filename) {
 			}
 			else {
 				/* skip this segment */
-				uint32 sz;
+				uint32_t sz;
 				get32(&sz,fp);
 				fseek(fp,sz,SEEK_CUR);
 			}
@@ -2089,12 +2048,12 @@ bool TCOD_console_load_apf(TCOD_console_t pcon, const char *filename) {
 			for(y = 0; y < con->h; y++) {
 	    	TCOD_color_t fore,back;
 		    int c = (unsigned char)(imgData[index++]);
-		    fore.r = (uint8)(imgData[index++]);
-		    fore.g = (uint8)(imgData[index++]);
-		    fore.b = (uint8)(imgData[index++]);
-		    back.r = (uint8)(imgData[index++]);
-		    back.g = (uint8)(imgData[index++]);
-		    back.b = (uint8)(imgData[index++]);
+		    fore.r = (uint8_t)(imgData[index++]);
+		    fore.g = (uint8_t)(imgData[index++]);
+		    fore.b = (uint8_t)(imgData[index++]);
+		    back.r = (uint8_t)(imgData[index++]);
+		    back.g = (uint8_t)(imgData[index++]);
+		    back.b = (uint8_t)(imgData[index++]);
 		    TCOD_console_put_char_ex(con,x,y,c,fore,back);
 			}
 		}
@@ -2110,11 +2069,11 @@ bool TCOD_console_load_apf(TCOD_console_t pcon, const char *filename) {
 bool ApfFile::Load(std::string filename){
 	detectBigEndianness();
 
-	uint32 sett = fourCC("sett");
-	uint32 imgd = fourCC("imgd");
-	uint32 LIST = fourCC("LIST");
-	uint32 LAYR = fourCC("LAYR");
-	uint32 layr = fourCC("layr");
+	uint32_t sett = fourCC("sett");
+	uint32_t imgd = fourCC("imgd");
+	uint32_t LIST = fourCC("LIST");
+	uint32_t LAYR = fourCC("LAYR");
+	uint32_t layr = fourCC("layr");
 
 	Data data; // File data
 
@@ -2139,25 +2098,25 @@ bool ApfFile::Load(std::string filename){
 	}
 	else {
 		// read the header
-		uint32 riff;
+		uint32_t riff;
 		if (not get32(&riff,fp)
 			or
 			not fourCCequals(riff,"RIFF")){
 			ERR("File doesn't have a RIFF header");
 		}
 		// else
-		uint32 riffSize;
+		uint32_t riffSize;
 		if (!get32(&riffSize,fp)) ERR("No RIFF size field!");
 		fix(&riffSize);
 
 		bool keepGoing = true;
 		while(keepGoing and fp){ // for each subfield, try to find the APF_ field
-			uint32 apf;
+			uint32_t apf;
 			if (not get32(&apf,fp)) break;
 			if (fourCCequals(apf,"apf ") or fourCCequals(apf,"APF ")){
 				// Process APF segment
 				while(keepGoing and fp){
-					uint32 seg;
+					uint32_t seg;
 					if (not get32(&seg,fp)){
 						keepGoing = false;
 						break;
@@ -2165,11 +2124,11 @@ bool ApfFile::Load(std::string filename){
 					else {
 						if (seg==sett){
 							// size
-							uint32 sz;
+							uint32_t sz;
 							get32(&sz,fp);
 							fix(&sz);
 							// version
-							uint32 ver;
+							uint32_t ver;
 							get32(&ver,fp);
 							fix(&ver);
 							if (ver!=1) ERR_NEWER("settings");
@@ -2185,11 +2144,11 @@ bool ApfFile::Load(std::string filename){
 						}
 						else if (seg==imgd){
 							// sz
-							uint32 sz;
+							uint32_t sz;
 							get32(&sz,fp);
 							fix(&sz);
 							// version
-							uint32 ver;
+							uint32_t ver;
 							get32(&ver,fp);
 							fix(&ver);
 							if (ver!=1) ERR_NEWER("image details");
@@ -2212,11 +2171,11 @@ bool ApfFile::Load(std::string filename){
 							// printf("Found a layer\n");
 
 							// sz
-							uint32 sz;
+							uint32_t sz;
 							get32(&sz,fp);
 							fix(&sz);
 							// version
-							uint32 ver;
+							uint32_t ver;
 							get32(&ver,fp);
 							fix(&ver);
 							if (ver>2) ERR_NEWER("layer spec");
@@ -2258,7 +2217,7 @@ bool ApfFile::Load(std::string filename){
 						}
 						else {
 							// skip unknown segment
-							uint32 sz;
+							uint32_t sz;
 							get32(&sz,fp);
 							fix(&sz);
 							fseek(fp,sz,SEEK_CUR);
@@ -2271,7 +2230,7 @@ bool ApfFile::Load(std::string filename){
 			}
 			else {
 				// skip this segment
-				uint32 sz;
+				uint32_t sz;
 				get32(&sz,fp);
 				fseek(fp,sz,SEEK_CUR);
 			}
@@ -2293,7 +2252,7 @@ bool ApfFile::Load(std::string filename){
 			// l->compositingMode =
 
 			// Copy data into currently selected canvas
-			uint8* imgData = ld->data;
+			uint8_t* imgData = ld->data;
 			CanvasImage *img = new CanvasImage;
 			// Write the brush data for every brush in the image
 			int index = 0;
@@ -2301,12 +2260,12 @@ bool ApfFile::Load(std::string filename){
 				for(int y = 0; y < app->canvasHeight; y++) {
 					Brush b;
 					b.symbol = (unsigned char)(imgData[index++]);
-					b.fore.r = (uint8)(imgData[index++]);
-					b.fore.g = (uint8)(imgData[index++]);
-					b.fore.b = (uint8)(imgData[index++]);
-					b.back.r = (uint8)(imgData[index++]);
-					b.back.g = (uint8)(imgData[index++]);
-					b.back.b = (uint8)(imgData[index++]);
+					b.fore.r = (uint8_t)(imgData[index++]);
+					b.fore.g = (uint8_t)(imgData[index++]);
+					b.fore.b = (uint8_t)(imgData[index++]);
+					b.back.r = (uint8_t)(imgData[index++]);
+					b.back.g = (uint8_t)(imgData[index++]);
+					b.back.b = (uint8_t)(imgData[index++]);
 					b.solid = true; // deprecated
 					b.walkable = true; // deprecated
 					img->push_back(b);
@@ -2331,3 +2290,5 @@ bool ApfFile::Load(std::string filename){
 	return true;
 }
 */
+
+#endif /* TCOD_CONSOLE_SUPPORT */
