@@ -1,5 +1,5 @@
 /*
-* libtcod 1.6.3
+* libtcod 1.6.4
 * Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
@@ -28,10 +28,12 @@
 /*
 * Mingos' Restrictive Precise Angle Shadowcasting (MRPAS) v1.2
 */
+#include <fov.h>
 
 #include <stdlib.h> /* for NULL in VS */
-#include "libtcod.h"
-#include "libtcod_int.h"
+
+#include <libtcod_int.h>
+#include <libtcod_utility.h>
 
 /* angle ranges */
 double * start_angle = NULL;
