@@ -1,5 +1,5 @@
 /*
-* libtcod 1.6.3
+* libtcod 1.6.4
 * Copyright (c) 2008,2009,2010,2012,2013,2016,2017 Jice & Mingos & rmtew
 * All rights reserved.
 *
@@ -24,11 +24,20 @@
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
+#include <libtcod_portability.h>
+
+#ifdef TCOD_IMAGE_SUPPORT
+
 #include <stdlib.h>
 #include <stdarg.h>
 #include <math.h>
-#include "libtcod.h"
-#include "libtcod_int.h"
+
+#include <image.h>
+#ifdef TCOD_CONSOLE_SUPPORT
+#include <console.h>
+#endif
+#include <libtcod_int.h>
+#include <libtcod_utility.h>
 
 typedef struct {
 	int width,height;
@@ -292,7 +301,9 @@ void TCOD_image_delete_internal(TCOD_image_t image) {
 		free(img->mipmaps);
 	}
 	if ( img->sys_img ) {
+#ifdef TCOD_SDL2
 		TCOD_sys_delete_bitmap(img->sys_img);
+#endif
 	}
 }
 
@@ -312,6 +323,8 @@ bool TCOD_image_is_pixel_transparent(TCOD_image_t image, int x, int y) {
 	return false;
 }
 
+#ifdef TCOD_CONSOLE_SUPPORT
+
 void TCOD_image_blit(TCOD_image_t image, TCOD_console_t console, float x, float y,
 	TCOD_bkgnd_flag_t bkgnd_flag, float scalex, float scaley, float angle) {
 	int width,height;
@@ -423,16 +436,14 @@ TCOD_image_t TCOD_image_from_console(TCOD_console_t console) {
 
 void TCOD_image_refresh_console(TCOD_image_t image, TCOD_console_t console) {
 	image_data_t *img=(image_data_t *)image;
-
+	console = (console?console:TCOD_ctx.root);
 	/* We're copying the state and clearing part of the copy, no need to delete/free. */
-	TCOD_render_state_t partial_render_state = *TCOD_console_get_render_state(console);
-	partial_render_state.oldbuf = NULL;
-	partial_render_state.bg_colors_prev = NULL;
-	partial_render_state.fg_colors_prev = NULL;
-	TCOD_sys_console_to_bitmap(img->sys_img, TCOD_console_get_width(console), TCOD_console_get_height(console),
-		&partial_render_state);
+	TCOD_sys_console_to_bitmap(
+		img->sys_img, (TCOD_console_data_t*)console, NULL);
 }
 
+#endif /* TCOD_CONSOLE_SUPPORT */
+
 void TCOD_image_save(TCOD_image_t image, const char *filename) {
 	image_data_t *img=(image_data_t *)image;
 	void *bitmap=NULL;
@@ -773,6 +784,8 @@ void getPattern(TCOD_color_t desired[4], TCOD_color_t palette[2], int *nbCols, i
 	*ascii=flagToAscii[flag];
 }
 
+#ifdef TCOD_CONSOLE_SUPPORT
+
 void TCOD_image_blit_2x(TCOD_image_t image, TCOD_console_t con, int dx, int dy, int sx, int sy, int w, int h) {
 	TCOD_color_t grid[4];
 	TCOD_color_t cols[2];
@@ -835,19 +848,20 @@ void TCOD_image_blit_2x(TCOD_image_t image, TCOD_console_t con, int dx, int dy,
 				TCOD_console_set_char(con,conx,cony,' ');
 			} else {
 				if ( ascii >= 0 ) {
-					TCOD_console_set_default_background(con,cols[0]);
-					TCOD_console_set_default_foreground(con,cols[1]);
-					TCOD_console_put_char(con,conx,cony,ascii,TCOD_BKGND_SET);
+					TCOD_console_set_char_background(con,conx,cony,cols[0],TCOD_BKGND_SET);
+					TCOD_console_set_char_foreground(con,conx,cony,cols[1]);
+					TCOD_console_set_char(con,conx,cony,ascii);
 				} else {
 					/* negative ascii code means we need to invert back/fore colors */
-					TCOD_console_set_default_background(con,cols[1]);
-					TCOD_console_set_default_foreground(con,cols[0]);
-					TCOD_console_put_char(con,conx,cony,-ascii,TCOD_BKGND_SET);
+					TCOD_console_set_char_background(con,conx,cony,cols[1],TCOD_BKGND_SET);
+					TCOD_console_set_char_foreground(con,conx,cony,cols[0]);
+					TCOD_console_set_char(con,conx,cony,-ascii);
 				}
 			}
 		}
 	}
 }
 
+#endif /* TCOD_CONSOLE_SUPPORT */
 
-
+#endif /* TCOD_IMAGE_SUPPORT */
